@@ -3,7 +3,9 @@ package App::XML::DocBook::Builder;
 use warnings;
 use strict;
 
-use base 'Class::Accessor';
+use 5.008;
+
+use parent 'Class::Accessor';
 
 =head1 NAME
 
@@ -11,11 +13,11 @@ App::XML::DocBook::Builder - Build DocBook/XML files.
 
 =head1 VERSION
 
-Version 0.0402
+Version 0.0403
 
 =cut
 
-our $VERSION = '0.0402';
+our $VERSION = '0.0403';
 
 =head1 SYNOPSIS
 
